@@ -1,6 +1,7 @@
 import os
 from contextlib import contextmanager
 from datetime import datetime, timezone
+from pydantic import ValidationError
 from uuid import UUID
 from sqlalchemy import MetaData, text
 from sqlalchemy.engine import Engine, create_engine
@@ -16,6 +17,8 @@ from maleo.soma.enums.operation import (
     SystemOperationType,
 )
 from maleo.soma.exceptions import (
+    Error,
+    UnprocessableEntity,
     InternalServerError,
     DatabaseError,
 )
@@ -156,6 +159,28 @@ class SessionManager:
             )
             error.operation_schema.log(logger=self._logger, level=LogLevel.ERROR)
             raise error from se
+        except ValidationError as ve:
+            session.rollback()  # Rollback on error
+            completed_at = datetime.now(tz=timezone.utc)
+            error = UnprocessableEntity(
+                service_context=self._service_context,
+                operation_id=operation_id,
+                operation_context=operation_context,
+                operation_timestamp=OperationTimestamp(
+                    executed_at=executed_at,
+                    completed_at=completed_at,
+                    duration=(completed_at - executed_at).total_seconds(),
+                ),
+                operation_summary="Validation error occured while handling database session",
+                request_context=request_context,
+                authentication=authentication,
+                operation_action=operation_action,
+                details=ve.errors(),
+            )
+            error.operation_schema.log(logger=self._logger, level=LogLevel.ERROR)
+            raise error from ve
+        except Error:
+            raise
         except Exception as e:
             session.rollback()  # Rollback on error
             completed_at = datetime.now(tz=timezone.utc)
