@@ -4,6 +4,7 @@ from maleo.soma.mixins.parameter import (
     IdentifierValueT,
     IdentifierTypeValue,
     ListOfDataStatuses,
+    StatusUpdateAction,
     UseCache,
 )
 
@@ -21,3 +22,7 @@ class ReadSingleParameterSchema(
     Generic[IdentifierTypeT, IdentifierValueT],
 ):
     pass
+
+
+class StatusUpdateQueryParameterSchema(StatusUpdateAction):
+    pass
